# author   : Johann-Mattis List
# email    : mattis.list@gmail.com
# created  : 2013-04-11 07:50
# modified : 2013-09-05 18:35
"""
Basic module for the evaluation of algorithms.
"""

__author__="Johann-Mattis List"
__date__="2013-09-05"


from .acd import bcubes, diff, pairs
from .apa import EvalMSA, EvalPSA
from .alr import mean_edit_distance
